update_citation_message_ids

Function update_citation_message_ids 

pub async fn update_citation_message_ids(
    conn: &mut PgConnection,
    response_id: String,
    conversation_message_id: Uuid,
) -> ModelResult<Vec<ChatbotConversationMessageCitation>>
Sets the correct conversation_message_id to citations. The correct id is the id of the chatbot text message that uses the citations. Update the citations that currently connected to a conversation_message that contains tool output and has the same response_id.